from setuptools import setup, find_packages

setup(
    name='matrixswarm',
    version='1.0.18',
    description='Open-source automation and monitoring platform',
    author='MatrixSwarm Core Team (Daniel F. MacDonald, ChatGPT) AKA The Generals, Gemini Docstring Engineer',
    author_email='swarm@matrixswarm.com',
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown", 
    packages=find_packages(include=["matrixswarm", "matrixswarm.*"]),
    install_requires=[
    "aiohappyeyeballs==2.6.1",
    "aiohttp==3.12.13",
    "aiosignal==1.3.2",
    "attrs==25.3.0",
    "blinker==1.9.0",
    "certifi==2025.6.15",
    "cffi==1.17.1",
    "charset-normalizer==3.4.2",
    "click>=8.0.0,<8.2.0",
    "cryptography==45.0.4",
    "dotenv==0.9.9",
    "Flask==3.1.1",
    "frozenlist==1.7.0",
    "geoip2==5.1.0",
    "gevent==25.5.1",
    "greenlet==3.2.3",
    "idna==3.10",
    "inotify==0.2.10",
    "itsdangerous==2.2.0",
    "Jinja2==3.1.6",
    "MarkupSafe==3.0.2",
    "maxminddb==2.7.0",
    "multidict==6.5.1",
    "nose==1.3.7",
    "propcache==0.3.2",
    "psutil==7.0.0",
    "py-cord==2.6.1",
    "pycparser==2.22",
    "pycryptodome==3.23.0",
    "python-dotenv==1.1.1",
    "requests==2.32.4",
    "setuptools==80.9.0",
    "urllib3==2.5.0",
    "websocket==0.2.1",
    "websockets==15.0.1",
    "Werkzeug==3.1.3",
    "yarl==1.20.1",
    "zope.event==5.1",
    "zope.interface==7.2",
    "eventlet",
    "watchdog",
    "openai",
    "bleach",
    ],
    entry_points={
        'console_scripts': [
            'matrixswarm-boot=matrixswarm.site_boot:main',
            'matrixswarm-kill=matrixswarm.site_kill:main',
            'matrixswarm-list=matrixswarm.site_list:main',
            'matrixswarm-encrypt-directive=matrixswarm.encrypt_directive:main',
            'matrixswarm-gencerts=matrixswarm.tools.generate_certs:main',
        ],
    },
    python_requires='>=3.8',
    include_package_data = True
)
